@@ -93,6 +93,7 @@ func (a *App) Deps(c DepsConfigProvider) error {
 			SkipRepos:   c.SkipRepos(),
 			SkipDeps:    true,
 			SkipResolve: true,
+			Concurrency: c.Concurrency(),
 		}, func() {
 			errs = run.Deps(c)
 		})
@@ -120,8 +121,9 @@ func (a *App) Repos(c ReposConfigProvider) error {
 func (a *App) DeprecatedSyncCharts(c DeprecatedChartsConfigProvider) error {
 	return a.ForEachState(func(run *Run) (_ bool, errs []error) {
 		err := run.withPreparedCharts("charts", state.ChartPrepareOptions{
-			SkipRepos: true,
-			SkipDeps:  true,
+			SkipRepos:   true,
+			SkipDeps:    true,
+			Concurrency: 2,
 		}, func() {
 			errs = run.DeprecatedSyncCharts(c)
 		})
@@ -155,6 +157,7 @@ func (a *App) Diff(c DiffConfigProvider) error {
 			SkipDeps:    c.SkipDeps(),
 			IncludeCRDs: &includeCRDs,
 			Validate:    c.Validate(),
+			Concurrency: c.Concurrency(),
 		}, func() {
 			msg, matched, affected, errs = a.diff(run, c)
 		})
@@ -219,6 +222,7 @@ func (a *App) Template(c TemplateConfigProvider) error {
 			IncludeCRDs:   &includeCRDs,
 			SkipCleanup:   c.SkipCleanup(),
 			Validate:      c.Validate(),
+			Concurrency:   c.Concurrency(),
 		}, func() {
 			ok, errs = a.template(run, c)
 		})
@@ -240,6 +244,7 @@ func (a *App) WriteValues(c WriteValuesConfigProvider) error {
 			SkipRepos:     c.SkipDeps(),
 			SkipDeps:      c.SkipDeps(),
 			SkipCleanup:   c.SkipCleanup(),
+			Concurrency:   c.Concurrency(),
 		}, func() {
 			ok, errs = a.writeValues(run, c)
 		})
@@ -290,6 +295,7 @@ func (a *App) Lint(c LintConfigProvider) error {
 			SkipRepos:     c.SkipDeps(),
 			SkipDeps:      c.SkipDeps(),
 			SkipCleanup:   c.SkipCleanup(),
+			Concurrency:   c.Concurrency(),
 		}, func() {
 			ok, lintErrs, errs = a.lint(run, c)
 		})
@@ -323,6 +329,7 @@ func (a *App) Fetch(c FetchConfigProvider) error {
 			SkipRepos:     c.SkipDeps(),
 			SkipDeps:      c.SkipDeps(),
 			OutputDir:     c.OutputDir(),
+			Concurrency:   c.Concurrency(),
 		}, func() {
 		})
 
@@ -346,6 +353,7 @@ func (a *App) Sync(c SyncConfigProvider) error {
 			IncludeCRDs:            &includeCRDs,
 			IncludeTransitiveNeeds: c.IncludeTransitiveNeeds(),
 			Validate:               c.Validate(),
+			Concurrency:            c.Concurrency(),
 		}, func() {
 			ok, errs = a.sync(run, c)
 		})
@@ -378,6 +386,7 @@ func (a *App) Apply(c ApplyConfigProvider) error {
 			IncludeCRDs: &includeCRDs,
 			SkipCleanup: c.RetainValuesFiles() || c.SkipCleanup(),
 			Validate:    c.Validate(),
+			Concurrency: c.Concurrency(),
 		}, func() {
 			matched, updated, es := a.apply(run, c)
 
@@ -411,8 +420,9 @@ func (a *App) Apply(c ApplyConfigProvider) error {
 func (a *App) Status(c StatusesConfigProvider) error {
 	return a.ForEachState(func(run *Run) (ok bool, errs []error) {
 		err := run.withPreparedCharts("status", state.ChartPrepareOptions{
-			SkipRepos: true,
-			SkipDeps:  true,
+			SkipRepos:   true,
+			SkipDeps:    true,
+			Concurrency: c.Concurrency(),
 		}, func() {
 			ok, errs = a.status(run, c)
 		})
@@ -428,8 +438,9 @@ func (a *App) Status(c StatusesConfigProvider) error {
 func (a *App) Delete(c DeleteConfigProvider) error {
 	return a.ForEachState(func(run *Run) (ok bool, errs []error) {
 		err := run.withPreparedCharts("delete", state.ChartPrepareOptions{
-			SkipRepos: c.SkipDeps(),
-			SkipDeps:  c.SkipDeps(),
+			SkipRepos:   c.SkipDeps(),
+			SkipDeps:    c.SkipDeps(),
+			Concurrency: c.Concurrency(),
 		}, func() {
 			ok, errs = a.delete(run, c.Purge(), c)
 		})
@@ -445,8 +456,9 @@ func (a *App) Delete(c DeleteConfigProvider) error {
 func (a *App) Destroy(c DestroyConfigProvider) error {
 	return a.ForEachState(func(run *Run) (ok bool, errs []error) {
 		err := run.withPreparedCharts("destroy", state.ChartPrepareOptions{
-			SkipRepos: c.SkipDeps(),
-			SkipDeps:  c.SkipDeps(),
+			SkipRepos:   c.SkipDeps(),
+			SkipDeps:    c.SkipDeps(),
+			Concurrency: c.Concurrency(),
 		}, func() {
 			ok, errs = a.delete(run, true, c)
 		})
@@ -468,8 +480,9 @@ func (a *App) Test(c TestConfigProvider) error {
 		}
 
 		err := run.withPreparedCharts("test", state.ChartPrepareOptions{
-			SkipRepos: c.SkipDeps(),
-			SkipDeps:  c.SkipDeps(),
+			SkipRepos:   c.SkipDeps(),
+			SkipDeps:    c.SkipDeps(),
+			Concurrency: c.Concurrency(),
 		}, func() {
 			errs = a.test(run, c)
 		})
@@ -485,8 +498,9 @@ func (a *App) Test(c TestConfigProvider) error {
 func (a *App) PrintState(c StateConfigProvider) error {
 	return a.ForEachState(func(run *Run) (_ bool, errs []error) {
 		err := run.withPreparedCharts("build", state.ChartPrepareOptions{
-			SkipRepos: true,
-			SkipDeps:  true,
+			SkipRepos:   true,
+			SkipDeps:    true,
+			Concurrency: 2,
 		}, func() {
 			if c.EmbedValues() {
 				for i := range run.state.Releases {
@@ -533,54 +547,31 @@ func (a *App) ListReleases(c ListConfigProvider) error {
 	var releases []*HelmRelease
 
 	err := a.ForEachState(func(run *Run) (_ bool, errs []error) {
-		err := run.withPreparedCharts("list", state.ChartPrepareOptions{
-			SkipRepos: true,
-			SkipDeps:  true,
-		}, func() {
-			// var releases m
-			for _, r := range run.state.Releases {
-				labels := ""
-				if r.Labels == nil {
-					r.Labels = map[string]string{}
-				}
-				for k, v := range run.state.CommonLabels {
-					r.Labels[k] = v
-				}
+		var stateReleases []*HelmRelease
+		var err error
 
-				var keys []string
-				for k := range r.Labels {
-					keys = append(keys, k)
-				}
-				sort.Strings(keys)
-
-				for _, k := range keys {
-					v := r.Labels[k]
-					labels = fmt.Sprintf("%s,%s:%s", labels, k, v)
-				}
-				labels = strings.Trim(labels, ",")
-
-				enabled, err := state.ConditionEnabled(r, run.state.Values())
+		if !c.SkipCharts() {
+			err = run.withPreparedCharts("list", state.ChartPrepareOptions{
+				SkipRepos:   true,
+				SkipDeps:    true,
+				Concurrency: 2,
+			}, func() {
+				rel, err := a.list(run)
 				if err != nil {
 					panic(err)
 				}
-
-				installed := r.Installed == nil || *r.Installed
-				releases = append(releases, &HelmRelease{
-					Name:      r.Name,
-					Namespace: r.Namespace,
-					Installed: installed,
-					Enabled:   enabled,
-					Labels:    labels,
-					Chart:     r.Chart,
-					Version:   r.Version,
-				})
-			}
-		})
+				stateReleases = rel
+			})
+		} else {
+			stateReleases, err = a.list(run)
+		}
 
 		if err != nil {
 			errs = append(errs, err)
 		}
 
+		releases = append(releases, stateReleases...)
+
 		return
 	}, false, SetFilter(true))
 
@@ -597,6 +588,50 @@ func (a *App) ListReleases(c ListConfigProvider) error {
 	return err
 }
 
+func (a *App) list(run *Run) ([]*HelmRelease, error) {
+	var releases []*HelmRelease
+
+	for _, r := range run.state.Releases {
+		labels := ""
+		if r.Labels == nil {
+			r.Labels = map[string]string{}
+		}
+		for k, v := range run.state.CommonLabels {
+			r.Labels[k] = v
+		}
+
+		var keys []string
+		for k := range r.Labels {
+			keys = append(keys, k)
+		}
+		sort.Strings(keys)
+
+		for _, k := range keys {
+			v := r.Labels[k]
+			labels = fmt.Sprintf("%s,%s:%s", labels, k, v)
+		}
+		labels = strings.Trim(labels, ",")
+
+		enabled, err := state.ConditionEnabled(r, run.state.Values())
+		if err != nil {
+			return nil, err
+		}
+
+		installed := r.Installed == nil || *r.Installed
+		releases = append(releases, &HelmRelease{
+			Name:      r.Name,
+			Namespace: r.Namespace,
+			Installed: installed,
+			Enabled:   enabled,
+			Labels:    labels,
+			Chart:     r.Chart,
+			Version:   r.Version,
+		})
+	}
+
+	return releases, nil
+}
+
 func (a *App) within(dir string, do func() error) error {
 	if dir == "." {
 		return do()
@@ -1297,7 +1332,7 @@ Do you really want to apply?
 		a.Logger.Debug(*infoMsg)
 	}
 
-	syncErrs := []error{}
+	applyErrs := []error{}
 
 	affectedReleases := state.AffectedReleases{}
 
@@ -1325,7 +1360,7 @@ Do you really want to apply?
 			}))
 
 			if len(deletionErrs) > 0 {
-				syncErrs = append(syncErrs, deletionErrs...)
+				applyErrs = append(applyErrs, deletionErrs...)
 			}
 		}
 
@@ -1354,13 +1389,13 @@ Do you really want to apply?
 			}))
 
 			if len(updateErrs) > 0 {
-				syncErrs = append(syncErrs, updateErrs...)
+				applyErrs = append(applyErrs, updateErrs...)
 			}
 		}
 	}
 
 	affectedReleases.DisplayAffectedReleases(c.Logger())
-	return true, true, syncErrs
+	return true, true, applyErrs
 }
 
 func (a *App) delete(r *Run, purge bool, c DestroyConfigProvider) (bool, []error) {
@@ -1663,7 +1698,16 @@ func (a *App) sync(r *Run, c SyncConfigProvider) (bool, []error) {
 %s
 `, strings.Join(names, "\n"))
 
-	a.Logger.Info(infoMsg)
+	confMsg := fmt.Sprintf(`%s
+Do you really want to sync?
+  Helmfile will sync all your releases, as shown above.
+
+`, infoMsg)
+
+	interactive := c.Interactive()
+	if !interactive {
+		a.Logger.Debug(infoMsg)
+	}
 
 	var errs []error
 
@@ -1674,51 +1718,53 @@ func (a *App) sync(r *Run, c SyncConfigProvider) (bool, []error) {
 
 	affectedReleases := state.AffectedReleases{}
 
-	if len(releasesToDelete) > 0 {
-		_, deletionErrs := withDAG(st, helm, a.Logger, state.PlanOptions{Reverse: true, SelectedReleases: toDelete, SkipNeeds: true}, a.WrapWithoutSelector(func(subst *state.HelmState, helm helmexec.Interface) []error {
-			var rs []state.ReleaseSpec
+	if !interactive || interactive && r.askForConfirmation(confMsg) {
+		if len(releasesToDelete) > 0 {
+			_, deletionErrs := withDAG(st, helm, a.Logger, state.PlanOptions{Reverse: true, SelectedReleases: toDelete, SkipNeeds: true}, a.WrapWithoutSelector(func(subst *state.HelmState, helm helmexec.Interface) []error {
+				var rs []state.ReleaseSpec
 
-			for _, r := range subst.Releases {
-				release := r
-				if r2, ok := releasesToDelete[state.ReleaseToID(&release)]; ok {
-					rs = append(rs, r2)
+				for _, r := range subst.Releases {
+					release := r
+					if r2, ok := releasesToDelete[state.ReleaseToID(&release)]; ok {
+						rs = append(rs, r2)
+					}
 				}
+
+				subst.Releases = rs
+
+				return subst.DeleteReleasesForSync(&affectedReleases, helm, c.Concurrency())
+			}))
+
+			if len(deletionErrs) > 0 {
+				errs = append(errs, deletionErrs...)
 			}
-
-			subst.Releases = rs
-
-			return subst.DeleteReleasesForSync(&affectedReleases, helm, c.Concurrency())
-		}))
-
-		if len(deletionErrs) > 0 {
-			errs = append(errs, deletionErrs...)
 		}
-	}
 
-	if len(releasesToUpdate) > 0 {
-		_, syncErrs := withDAG(st, helm, a.Logger, state.PlanOptions{SelectedReleases: toUpdate, SkipNeeds: true, IncludeTransitiveNeeds: c.IncludeTransitiveNeeds()}, a.WrapWithoutSelector(func(subst *state.HelmState, helm helmexec.Interface) []error {
-			var rs []state.ReleaseSpec
+		if len(releasesToUpdate) > 0 {
+			_, syncErrs := withDAG(st, helm, a.Logger, state.PlanOptions{SelectedReleases: toUpdate, SkipNeeds: true, IncludeTransitiveNeeds: c.IncludeTransitiveNeeds()}, a.WrapWithoutSelector(func(subst *state.HelmState, helm helmexec.Interface) []error {
+				var rs []state.ReleaseSpec
 
-			for _, r := range subst.Releases {
-				release := r
-				if _, ok := releasesToDelete[state.ReleaseToID(&release)]; !ok {
-					rs = append(rs, release)
+				for _, r := range subst.Releases {
+					release := r
+					if _, ok := releasesToDelete[state.ReleaseToID(&release)]; !ok {
+						rs = append(rs, release)
+					}
 				}
+
+				subst.Releases = rs
+
+				opts := &state.SyncOpts{
+					Set:         c.Set(),
+					SkipCRDs:    c.SkipCRDs(),
+					Wait:        c.Wait(),
+					WaitForJobs: c.WaitForJobs(),
+				}
+				return subst.SyncReleases(&affectedReleases, helm, c.Values(), c.Concurrency(), opts)
+			}))
+
+			if len(syncErrs) > 0 {
+				errs = append(errs, syncErrs...)
 			}
-
-			subst.Releases = rs
-
-			opts := &state.SyncOpts{
-				Set:         c.Set(),
-				SkipCRDs:    c.SkipCRDs(),
-				Wait:        c.Wait(),
-				WaitForJobs: c.WaitForJobs(),
-			}
-			return subst.SyncReleases(&affectedReleases, helm, c.Values(), c.Concurrency(), opts)
-		}))
-
-		if len(syncErrs) > 0 {
-			errs = append(errs, syncErrs...)
 		}
 	}
 	affectedReleases.DisplayAffectedReleases(c.Logger())
