@@ -10,6 +10,8 @@ type DeleteOptions struct {
 	Purge bool
 	// SkipDeps is the skip deps flag
 	SkipDeps bool
+	// Interactive is true if the user should be prompted for input.
+	Interactive bool
 }
 
 // NewDeleteOptions creates a new Apply
@@ -50,3 +52,8 @@ func (c *DeleteImpl) Purge() bool {
 func (c *DeleteImpl) SkipDeps() bool {
 	return c.DeleteOptions.SkipDeps
 }
+
+// Interactive returns the Interactive
+func (c *DeleteImpl) Interactive() bool {
+	return c.DeleteOptions.Interactive
+}
