@@ -26,6 +26,8 @@ type SyncOptions struct {
 	Wait bool
 	// WaitForJobs is the wait for jobs flag
 	WaitForJobs bool
+	// Interactive is true if the user should be prompted for input.
+	Interactive bool
 }
 
 // NewSyncOptions creates a new Apply
@@ -59,7 +61,7 @@ func (t *SyncImpl) Concurrency() int {
 
 // IncludeNeeds returns the include needs
 func (t *SyncImpl) IncludeNeeds() bool {
-	return t.SyncOptions.IncludeNeeds || t.SyncOptions.IncludeTransitiveNeeds
+	return t.SyncOptions.IncludeNeeds || t.IncludeTransitiveNeeds()
 }
 
 // IncludeTransitiveNeeds returns the include transitive needs
@@ -79,7 +81,7 @@ func (t *SyncImpl) SkipDeps() bool {
 
 // SkipNeeds returns the skip needs
 func (t *SyncImpl) SkipNeeds() bool {
-	if !t.SyncOptions.IncludeNeeds {
+	if !t.IncludeNeeds() {
 		return t.SyncOptions.SkipNeeds
 	}
 
@@ -110,3 +112,8 @@ func (t *SyncImpl) Wait() bool {
 func (t *SyncImpl) WaitForJobs() bool {
 	return t.SyncOptions.WaitForJobs
 }
+
+// Interactive returns the Interactive
+func (t *SyncImpl) Interactive() bool {
+	return t.SyncOptions.Interactive
+}
